OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Značky",
    "Tagged files" : "Otagované soubory",
    "Select tags to filter by" : "Vybrat tagy pro filtr",
    "Please select tags to filter by" : "Vyberte prosím tagy pro filtrování",
    "No files found for the selected tags" : "Nebyly nalezeny žádné soubory s vybranými tagy",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Systémové tagy</strong> souboru byly upraveny",
    "You assigned system tag %3$s" : "Přidělili jste systémový tag %3$s",
    "%1$s assigned system tag %3$s" : "%1$s přiřadil systémový tag %3$s",
    "You unassigned system tag %3$s" : "Odebrali jste systémový tag %3$s",
    "%1$s unassigned system tag %3$s" : "%1$s odebral systémový tag %3$s",
    "You created system tag %2$s" : "Vytvořili jste systémový tag %2$s",
    "%1$s created system tag %2$s" : "%1$s vytvořil systémový tag %2$s",
    "You deleted system tag %2$s" : "Smazali jste systémový tag %2$s",
    "%1$s deleted system tag %2$s" : "%1$s smazal systémový tag %2$s",
    "You updated system tag %3$s to %2$s" : "Aktualizovali jste systémový tag %3$s na %2$s",
    "%1$s updated system tag %3$s to %2$s" : "%1$s aktualizoval systémový tag %3$s na %2$s",
    "You assigned system tag %3$s to %2$s" : "Přiřadili jste systémový tag %3$s na %2$s",
    "%1$s assigned system tag %3$s to %2$s" : "%1$s přiřadil systémový tag %3$s na %2$s",
    "You unassigned system tag %3$s from %2$s" : "Odebrali jste systémový tag %3$s z %2$s",
    "%1$s unassigned system tag %3$s from %2$s" : "%1$s odebral systémový tag %3$s ze %2$s",
    "%s (restricted)" : "%s (omezeno)",
    "%s (invisible)" : "%s (neviditelný)",
    "No files in here" : "Žádné soubory",
    "No entries found in this folder" : "V tomto adresáři nebylo nic nalezeno",
    "Name" : "Název",
    "Size" : "Velikost",
    "Modified" : "Upraveno"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
